@@ -1063,7 +1063,7 @@ Bhv_PenaltyKick::getGoalieMovePos( const rcsc::Vector2D & ball_pos,
     rcsc::Line2D goal_line(goal_l, goal_r);
 
     rcsc::Vector2D intersection = goal_line.intersection( line_m );
-    if ( intersection )
+    if ( intersection.valid() )
     {
         rcsc::Line2D line_l( ball_pos, goal_l );
         rcsc::Line2D line_r( ball_pos, goal_r );
@@ -1185,7 +1185,7 @@ Bhv_PenaltyKick::doGoalieSlideChase( rcsc::PlayerAgent * agent )
 
 
     rcsc::Vector2D intersection = my_line.intersection( ball_line );
-    if ( ! intersection
+    if ( ! intersection.valid()
          || ! ball_ray.inRightDir( intersection ) )
     {
         rcsc::Body_Intercept( false ).execute( agent ); // goalie mode
