@@ -28,8 +28,9 @@
 #include <config.h>
 #endif
 
-#include <rcsc/param/server_param.h>
+#include <rcsc/common/server_param.h>
 
+#include <rcsc/player/audio_memory.h>
 #include <rcsc/player/logger.h>
 #include <rcsc/player/player_agent.h>
 #include <rcsc/player/intercept_table.h>
@@ -111,7 +112,8 @@ Bhv_PreProcess::execute( rcsc::PlayerAgent * agent )
         rcsc::dlog.addText( rcsc::Logger::TEAM,
                             "%s:%d: search ball"
                             ,__FILE__, __LINE__ );
-        agent->setViewAction( new rcsc::View_Synch() );
+        //agent->setViewAction( new rcsc::View_Synch() );
+        agent->setViewAction( new rcsc::View_Wide() );
         rcsc::Bhv_NeckBodyToBall().execute( agent );
         return true;
     }
@@ -169,13 +171,14 @@ Bhv_PreProcess::execute( rcsc::PlayerAgent * agent )
         rcsc::Body_KickOneStep( goal_pos,
                                 rcsc::ServerParam::i().ballSpeedMax()
                                 ).execute( agent );
+        agent->setNeckAction( new rcsc::Neck_ScanField() );
         return true;
     }
 
     //////////////////////////////////////////////////////////////
     // check communication intention
-    if ( agent->world().heardPassTime() == agent->world().time()
-         && agent->world().heardReceiverNumber() == agent->world().self().unum() )
+    if ( agent->world().audioMemory().passTime() == agent->world().time()
+         && agent->world().audioMemory().passReceiverNumber() == agent->world().self().unum() )
     {
         rcsc::dlog.addText( rcsc::Logger::TEAM,
                             "%s:%d: communication receive"
@@ -218,9 +221,9 @@ Bhv_PreProcess::doReceiveMove( rcsc::PlayerAgent * agent )
                         "%s:%d: PreProcess. Receiver. intercept cycle=%d. go to receive point"
                         ,__FILE__, __LINE__,
                         self_min );
-    agent->debugClient().setTarget( wm.heardReceivePos() );
+    agent->debugClient().setTarget( wm.audioMemory().passReceivePos() );
     agent->debugClient().addMessage( "GoTo" );
-    rcsc::Body_GoToPoint( wm.heardReceivePos(),
+    rcsc::Body_GoToPoint( wm.audioMemory().passReceivePos(),
                           0.5,
                           rcsc::ServerParam::i().maxPower()
                           ).execute( agent );
