@@ -30,7 +30,7 @@
 
 #include <rcsc/geom/ray_2d.h>
 #include <rcsc/geom/rect_2d.h>
-#include <rcsc/param/server_param.h>
+#include <rcsc/common/server_param.h>
 
 #include <rcsc/player/player_agent.h>
 #include <rcsc/player/intercept_table.h>
