@@ -28,7 +28,7 @@
 #include <config.h>
 #endif
 
-#include <rcsc/param/server_param.h>
+#include <rcsc/common/server_param.h>
 #include <rcsc/player/logger.h>
 #include <rcsc/player/player_agent.h>
 #include <rcsc/player/intercept_table.h>
