@@ -33,9 +33,10 @@
 #include <rcsc/coach/coach_command.h>
 #include <rcsc/coach/coach_config.h>
 #include <rcsc/coach/global_visual_sensor.h>
-#include <rcsc/param/player_param.h>
-#include <rcsc/param/server_param.h>
-#include <rcsc/param/player_type.h>
+#include <rcsc/common/basic_client.h>
+#include <rcsc/common/player_param.h>
+#include <rcsc/common/server_param.h>
+#include <rcsc/common/player_type.h>
 #include <rcsc/param/param_map.h>
 #include <rcsc/param/cmd_line_parser.h>
 
@@ -130,6 +131,7 @@ struct MaxSpeedReachStepCmp
 
  */
 SampleCoach::SampleCoach()
+    : CoachAgent()
 {
     for ( int i = 0; i < 11; ++i )
     {
@@ -150,6 +152,11 @@ SampleCoach::SampleCoach()
     M_forward_unum.push_back( 9 );
     M_forward_unum.push_back( 10 );
     M_forward_unum.push_back( 11 );
+
+    for ( int i = 0; i < 11; ++i )
+    {
+        M_opponent_player_types[i] = rcsc::Hetero_Default;
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -166,7 +173,7 @@ SampleCoach::~SampleCoach()
 
  */
 bool
-SampleCoach::doInit( rcsc::CmdLineParser & cmd_parser )
+SampleCoach::initImpl( rcsc::CmdLineParser & cmd_parser )
 {
     rcsc::ParamMap my_params;
 
@@ -177,10 +184,10 @@ SampleCoach::doInit( rcsc::CmdLineParser & cmd_parser )
         ;
 #endif
 
-    if ( ! CoachAgent::doInit( cmd_parser ) )
+    if ( ! rcsc::CoachAgent::initImpl( cmd_parser ) )
     {
         my_params.printHelp( std::cout );
-        setServerAlive( false );
+        M_client->setServerAlive( false );
         return false;
     }
 
@@ -205,28 +212,24 @@ SampleCoach::doInit( rcsc::CmdLineParser & cmd_parser )
 
  */
 void
-SampleCoach::doAction()
+SampleCoach::actionImpl()
 {
     doSubstitute();
+    sayPlayerTypes();
 
-    //visualSensor().print( std::cout );
-    //world().print( std::cout );
-#if 0
-    if ( world().canSendFreeform() )
-    {
-        char msg[128];
-        std::sprintf( msg, "freeform message %d/%d",
-                      world().freeformSendCount(),
-                      world().freeformAllowedCount() );
-        doSayFreeform( msg );
-    }
-#endif
-#if 1
-    if ( world().time().cycle() > 0 )
-    {
-        sendByeCommand();
-    }
-#endif
+//     if ( world().canSendFreeform() )
+//     {
+//         char msg[128];
+//         std::sprintf( msg, "freeform message %d/%d",
+//                       world().freeformSendCount(),
+//                       world().freeformAllowedCount() );
+//         doSayFreeform( msg );
+//     }
+
+//     if ( world().time().cycle() > 0 )
+//     {
+//         M_client->setServerAlive( false );
+//     }
 }
 
 /*-------------------------------------------------------------------*/
@@ -415,3 +418,72 @@ SampleCoach::getFastestType( const PlayerTypePtrCont & candidates )
 
     return besttype->id();
 }
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+SampleCoach::sayPlayerTypes()
+{
+    /*
+      format:
+      "(player_types (1 0) (2 1) (3 2) (4 3) (5 4) (6 5) (7 6) (8 -1) (9 0) (10 1) (11 2))"
+      ->
+      (say (freeform "(player_type ...)"))
+    */
+
+    static rcsc::GameTime s_last_send_time( 0, 0 );
+
+    if ( ! world().canSendFreeform() )
+    {
+        return;
+    }
+
+    int analyzed_count = 0;
+
+    for ( int unum = 1; unum <= 11; ++unum )
+    {
+        const rcsc::HeteroID id = world().getHeteroID( world().theirSide(), unum );
+
+        if ( id != M_opponent_player_types[unum - 1] )
+        {
+            M_opponent_player_types[unum - 1] = id;
+
+            if ( id != rcsc::Hetero_Unknown )
+            {
+                ++analyzed_count;
+            }
+        }
+    }
+
+    if ( analyzed_count == 0 )
+    {
+        return;
+    }
+
+    std::string msg;
+    msg.reserve( 128 );
+
+    msg = "(player_types ";
+
+    for ( int unum = 1; unum <= 11; ++unum )
+    {
+        char buf[8];
+        std::snprintf( buf, 8, "(%d %d)",
+                       unum, M_opponent_player_types[unum - 1] );
+        msg += buf;
+    }
+
+    msg += ")";
+
+    doSayFreeform( msg );
+
+    s_last_send_time = world().time();
+
+    std::cout << config().teamName()
+              << " Coach: "
+              << world().time()
+              << " send freeform " << msg
+              << std::endl;
+}
