@@ -24,8 +24,8 @@
 
 /////////////////////////////////////////////////////////////////////
 
-#ifndef HELIOS_COACH_H
-#define HELIOS_COACH_H
+#ifndef AGENT2D_SAMPLE_COACH_H
+#define AGENT2D_SAMPLE_COACH_H
 
 #include <vector>
 #include <map>
@@ -58,7 +58,11 @@ private:
     //! uniform number of players that belongs to forward
     std::vector< int > M_forward_unum;
 
+    //! opponent player type info sent as the known player type
+    rcsc::HeteroID M_opponent_player_types[11];
+
 public:
+
     SampleCoach();
 
     virtual
@@ -84,6 +88,11 @@ private:
 
     rcsc::HeteroID getDefenderType( const PlayerTypePtrCont & candidates );
 
+    /*!
+      \brief broadcast opponent players' player types
+     */
+    void sayPlayerTypes();
+
 protected:
 
     /*!
@@ -91,11 +100,11 @@ protected:
       But you must call CoachrAgent::doInit() in this method.
     */
     virtual
-    bool doInit( rcsc::CmdLineParser & cmd_parser );
+    bool initImpl( rcsc::CmdLineParser & cmd_parser );
 
     //! main decision
     virtual
-    void doAction();
+    void actionImpl();
 
 };
 
