@@ -25,7 +25,7 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifndef AGENT2D_SAMPLE_PLAYER_H
-#define AGENT2D__PLAYER_H
+#define AGENT2D_SAMPLE_PLAYER_H
 
 #include <rcsc/player/player_agent.h>
 
@@ -33,6 +33,8 @@
 
 class SamplePlayer
     : public rcsc::PlayerAgent {
+private:
+
 protected:
     Strategy M_strategy;
 
@@ -43,33 +45,33 @@ public:
     virtual
     ~SamplePlayer();
 
-private:
-
-    /*!
-      set team info by side and uniform number info
-      this method is called at the last of analyzeInit().
-    */
-    virtual
-    void initTeam();
-
 protected:
 
     /*!
       You can override this method.
-      But you must call PlayerAgent::doInit() in this method.
+      But you must call PlayerAgent::initImpl() in this method.
     */
     virtual
-    bool doInit( rcsc::CmdLineParser & cmd_parser );
+    bool initImpl( rcsc::CmdLineParser & cmd_parser );
 
     //! main decision
     virtual
-    void doAction();
+    void actionImpl();
 
     //! communication decision
     virtual
-    void doCommunication();
+    void communicationImpl();
 
+private:
 
+    bool sayBall();
+    bool saySelf();
+    bool sayGoalie();
+    bool sayIntercept();
+    bool sayOffsideLine();
+    bool sayDefenseLine();
+
+    void attentiontoSomeone();
 };
 
 #endif
