@@ -39,13 +39,15 @@
 #include <set>
 
 #include <rcsc/game_mode.h>
-#include <rcsc/param/server_param.h>
+#include <rcsc/common/server_param.h>
 
 #include <rcsc/player/intercept_table.h>
 #include <rcsc/player/world_model.h>
 #include <rcsc/player/logger.h>
+#include <rcsc/formation/formation_static.h>
 #include <rcsc/formation/formation_bpn.h>
 #include <rcsc/formation/formation_dt.h>
+#include <rcsc/formation/formation_ngnet.h>
 #include <rcsc/formation/formation_uva.h>
 
 #include "role_sample.h"
@@ -68,8 +70,8 @@ const std::string Strategy::GOAL_KICK_OUR_CONF = "goal-kick-our.conf";
 const std::string Strategy::GOALIE_CATCH_OPP_CONF = "goalie-catch-opp.conf";
 const std::string Strategy::GOALIE_CATCH_OUR_CONF = "goalie-catch-our.conf";
 
-const std::string Strategy::DEFENSE_FORMATION_CONF = "defense-formation.conf";
-const std::string Strategy::OFFENSE_FORMATION_CONF = "offense-formation.conf";
+const std::string Strategy::DEFENSE_FORMATION_CONF = "normal-formation.conf";
+const std::string Strategy::OFFENSE_FORMATION_CONF = "normal-formation.conf";
 const std::string Strategy::KICKIN_OUR_FORMATION_CONF = "kickin-our-formation.conf";
 const std::string Strategy::SETPLAY_OUR_FORMATION_CONF = "setplay-our-formation.conf";
 
@@ -78,8 +80,7 @@ const std::string Strategy::SETPLAY_OUR_FORMATION_CONF = "setplay-our-formation.
 
 */
 Strategy::Strategy()
-    : M_before_kick_off_pos( 11 )
-    , M_goal_kick_opp_pos( 11 )
+    : M_goal_kick_opp_pos( 11 )
     , M_goal_kick_our_pos( 11 )
     , M_goalie_catch_opp_pos( 11 )
     , M_goalie_catch_our_pos( 11 )
@@ -95,8 +96,10 @@ Strategy::Strategy()
     M_role_factory[RoleSideForward::name()] = &RoleSideForward::create;
     M_role_factory[RoleCenterForward::name()] = &RoleCenterForward::create;
 
+    M_formation_factory[rcsc::FormationStatic::name()] = &rcsc::FormationStatic::create;
     M_formation_factory[rcsc::FormationBPN::name()] = &rcsc::FormationBPN::create;
     M_formation_factory[rcsc::FormationDT::name()] = &rcsc::FormationDT::create;
+    M_formation_factory[rcsc::FormationNGNet::name()] = &rcsc::FormationNGNet::create;
     M_formation_factory[rcsc::FormationUvA::name()] = &rcsc::FormationUvA::create;
 }
 
@@ -115,11 +118,20 @@ Strategy::read( const std::string & config_dir )
     }
 
     // before kick off
+    M_before_kick_off_formation
+        = readFormation( configpath + BEFORE_KICK_OFF_CONF );
+    if ( ! M_before_kick_off_formation )
+    {
+        std::cerr << "Failed to read before_kick_off formation" << std::endl;
+        return false;
+    }
+    /*
     if ( ! readStaticPositions( configpath + BEFORE_KICK_OFF_CONF,
                                 M_before_kick_off_pos ) )
     {
         return false;
     }
+    */
     // opponent goal kick
     if ( ! readStaticPositions( configpath + GOAL_KICK_OPP_CONF,
                                 M_goal_kick_opp_pos ) )
@@ -134,7 +146,7 @@ Strategy::read( const std::string & config_dir )
     }
     // opponent goalie catch
     if ( ! readStaticPositions( configpath + GOALIE_CATCH_OPP_CONF,
-                                M_goalie_catch_opp_pos) )
+                                M_goalie_catch_opp_pos ) )
     {
         return false;
     }
@@ -146,22 +158,30 @@ Strategy::read( const std::string & config_dir )
     }
 
     ///////////////////////////////////////////////////////////
-    if ( ! readOffenseFormation( configpath ) )
+    // offense area
+    M_offense_formation = readFormation( configpath + OFFENSE_FORMATION_CONF );
+    if ( ! M_offense_formation )
     {
         std::cerr << "Failed to read offense formation" << std::endl;
         return false;
     }
-    if ( ! readDefenseFormation( configpath ) )
+    // defense area
+    M_defense_formation = readFormation( configpath + DEFENSE_FORMATION_CONF );
+    if ( ! M_defense_formation )
     {
-        std::cerr << "Failed to read offense formation" << std::endl;
+        std::cerr << "Failed to read defense formation" << std::endl;
         return false;
     }
-    if ( ! readKickInOurFormation( configpath ) )
+    // kick_in our
+    M_kickin_our_formation = readFormation( configpath + KICKIN_OUR_FORMATION_CONF );
+    if ( ! M_kickin_our_formation )
     {
         std::cerr << "Failed to read kickin our formation" << std::endl;
         return false;
     }
-    if ( ! readSetPlayOurFormation( configpath ) )
+    // setplay our
+    M_setplay_our_formation = readFormation( configpath + SETPLAY_OUR_FORMATION_CONF );
+    if ( ! M_setplay_our_formation )
     {
         std::cerr << "Failed to read setplay our formation" << std::endl;
         return false;
@@ -198,8 +218,7 @@ Strategy::readFormation( const std::string & filepath )
         std::cerr << __FILE__ << ": " << __LINE__
                   << " ***ERROR*** failed to create formation [" << filepath << "]"
                   << std::endl;
-        return boost::shared_ptr< rcsc::Formation >
-            ( static_cast< rcsc::Formation * >( 0 ) );
+        return boost::shared_ptr< rcsc::Formation >();
     }
 
     if ( ! ptr->read( fin ) )
@@ -207,8 +226,7 @@ Strategy::readFormation( const std::string & filepath )
         std::cerr << __FILE__ << ": " << __LINE__
                   << " ***ERROR*** failed to read formation [" << filepath << "]"
                   << std::endl;
-        return boost::shared_ptr< rcsc::Formation >
-            ( static_cast< rcsc::Formation * >( 0 ) );
+        return boost::shared_ptr< rcsc::Formation >();
     }
 
     for ( int unum = 1; unum <= 11; ++unum )
@@ -219,8 +237,7 @@ Strategy::readFormation( const std::string & filepath )
                       << " ***ERROR*** Unsupported role name ["
                       << ptr->getRoleName( unum ) << "] is appered in ["
                       << filepath << "]" << std::endl;
-            return boost::shared_ptr< rcsc::Formation >
-                ( static_cast< rcsc::Formation * >( 0 ) );
+            return boost::shared_ptr< rcsc::Formation >();
         }
     }
 
@@ -307,117 +324,6 @@ Strategy::readStaticPositions( const std::string & filepath,
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
-bool
-Strategy::readBeforeKickOffPos( const std::string & configpath )
-{
-    std::vector< rcsc::Vector2D > positions;
-    if ( ! readStaticPositions( configpath + BEFORE_KICK_OFF_CONF,
-                                positions )  )
-    {
-        std::cerr << __FILE__ << ": " << __LINE__
-                  << " ***ERROR*** faled to read BeforeKickOffPos(1)" << std::endl;
-        return false;
-    }
-    if ( positions.size() != 11 )
-    {
-        std::cerr << __FILE__ << ": " << __LINE__
-                  << " ***ERROR*** faled to read BeforeKickOffPos(2)" << std::endl;
-        return false;
-    }
-    for ( int i = 0; i < 11; ++i )
-    {
-        M_before_kick_off_pos[i] = positions[i];
-    }
-    return true;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-bool
-Strategy::readGoalKickOppPos( const std::string & configpath )
-{
-    std::vector< rcsc::Vector2D > positions;
-    if ( ! readStaticPositions( configpath + GOAL_KICK_OPP_CONF,
-                                positions )  )
-    {
-        std::cerr << "***ERROR*** faled to read GoalKickOppPos(1)" << std::endl;
-        return false;
-    }
-    if ( positions.size() != 11 )
-    {
-        std::cerr << "***ERROR*** faled to read GoalKickOppPos(2)" << std::endl;
-        return false;
-    }
-    for ( int i = 0; i < 11; ++i )
-    {
-        M_goal_kick_opp_pos[i] = positions[i];
-    }
-    return true;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-bool
-Strategy::readGoalieCatchOurPos( const std::string & configpath )
-{
-    std::vector< rcsc::Vector2D > positions;
-    if ( ! readStaticPositions( configpath + GOALIE_CATCH_OUR_CONF,
-                                positions )  )
-    {
-        std::cerr << __FILE__ << ": " << __LINE__
-                  << " ***ERROR*** faled to read GoalieCatchOppPos(1)" << std::endl;
-        return false;
-    }
-    if ( positions.size() != 11 )
-    {
-        std::cerr << __FILE__ << ": " << __LINE__
-                  << " ***ERROR*** faled to read GoalieCatchppPos(2)" << std::endl;
-        return false;
-    }
-    for ( int i = 0; i < 11; ++i )
-    {
-        //std::cerr << i + 1 << " " << positions[i] << std::endl;
-        M_goalie_catch_our_pos[i] = positions[i];
-    }
-    return true;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-bool
-Strategy::readGoalieCatchOppPos( const std::string & configpath )
-{
-    std::vector< rcsc::Vector2D > positions;
-    if ( ! readStaticPositions( configpath + GOALIE_CATCH_OPP_CONF,
-                                positions )  )
-    {
-        std::cerr << __FILE__ << ": " << __LINE__
-                  << " ***ERROR*** faled to read GoalieCatchOppPos(1)" << std::endl;
-        return false;
-    }
-    if ( positions.size() != 11 )
-    {
-        std::cerr << __FILE__ << ": " << __LINE__
-                  << " ***ERROR*** faled to read GoalieCatchppPos(2)" << std::endl;
-        return false;
-    }
-    for ( int i = 0; i < 11; ++i )
-    {
-        M_goalie_catch_opp_pos[i] = positions[i];
-    }
-    return true;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
 */
 boost::shared_ptr< rcsc::Formation >
 Strategy::createFormation( const std::string & type_name ) const
@@ -488,16 +394,8 @@ Strategy::createRole( const int number,
 rcsc::Vector2D
 Strategy::getBeforeKickOffPos( const int number ) const
 {
-    if ( number < 1 || 11 < number )
-    {
-
-        std::cerr << __FILE__ << ": " << __LINE__
-                  << " ***ERROR*** Invalid player number " << number
-                  << std::endl;
-        return rcsc::Vector2D( -50.0, -30.0 );
-    }
-
-    return M_before_kick_off_pos[number - 1];
+    return M_before_kick_off_formation->getPosition( number,
+                                                     rcsc::Vector2D( 0.0, 0.0 ) );
 }
 
 /*-------------------------------------------------------------------*/
@@ -702,62 +600,6 @@ Strategy::getFormation( const rcsc::WorldModel & world ) const
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
-bool
-Strategy::readOffenseFormation( const std::string & configpath )
-{
-    std::string filepath = configpath + OFFENSE_FORMATION_CONF;
-
-    M_offense_formation = readFormation( filepath );
-
-    return ( M_offense_formation );
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-bool
-Strategy::readDefenseFormation( const std::string & configpath )
-{
-    std::string filepath = configpath + DEFENSE_FORMATION_CONF;
-
-    M_defense_formation = readFormation( filepath );
-
-    return ( M_defense_formation );
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-bool
-Strategy::readKickInOurFormation( const std::string & configpath )
-{
-    std::string filepath = configpath + KICKIN_OUR_FORMATION_CONF;
-
-    M_kickin_our_formation = readFormation( filepath );
-
-    return ( M_kickin_our_formation );
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-bool
-Strategy::readSetPlayOurFormation( const std::string & configpath )
-{
-    std::string filepath = configpath + SETPLAY_OUR_FORMATION_CONF;
-
-    M_setplay_our_formation = readFormation( filepath );
-
-    return ( M_setplay_our_formation );
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
 */
 Strategy::BallArea
 Strategy::get_ball_area( const rcsc::Vector2D & ball_pos )
